@@ -37,7 +37,7 @@ static const char* drmParseSysfs(FFDisplayServerResult* result)
             continue;
         }
 
-        unsigned width = 0, height = 0;
+        unsigned width = 0, height = 0, physicalWidth = 0, physicalHeight = 0;
         double refreshRate = 0;
         FF_STRBUF_AUTO_DESTROY name = ffStrbufCreate();
 
@@ -49,6 +49,7 @@ static const char* drmParseSysfs(FFDisplayServerResult* result)
         {
             ffEdidGetName(edidData, &name);
             ffEdidGetPreferredResolutionAndRefreshRate(edidData, &width, &height, &refreshRate);
+            ffEdidGetPhysicalSize(edidData, &physicalWidth, &physicalHeight);
         }
         else
         {
@@ -78,7 +79,9 @@ static const char* drmParseSysfs(FFDisplayServerResult* result)
             &name,
             FF_DISPLAY_TYPE_UNKNOWN,
             false,
-            0
+            0,
+            physicalWidth,
+            physicalHeight
         );
 
         ffStrbufSubstrBefore(&drmDir, drmDirLength);
@@ -217,6 +220,8 @@ static const char* drmConnectLibdrm(FFDisplayServerResult* result)
     if (nDevices < 0)
         return "drmGetDevices() failed";
 
+    FF_STRBUF_AUTO_DESTROY name = ffStrbufCreate();
+
     for (int iDev = 0; iDev < nDevices; ++iDev)
     {
         drmDevice* dev = devices[iDev];
@@ -225,6 +230,13 @@ static const char* drmConnectLibdrm(FFDisplayServerResult* result)
             continue;
 
         const char* path = dev->nodes[DRM_NODE_PRIMARY];
+
+        ffStrbufSetF(&name, "/sys/class/drm/%s/device/power/runtime_status", strrchr(path, '/') + 1);
+
+        char buffer[8] = "";
+        if (ffReadFileData(name.chars, strlen("suspend"), buffer) > 0 && ffStrStartsWith(buffer, "suspend"))
+            continue;
+
         FF_AUTO_CLOSE_FD int fd = open(path, O_RDONLY | O_CLOEXEC);
         if (fd < 0)
             continue;
@@ -289,7 +301,8 @@ static const char* drmConnectLibdrm(FFDisplayServerResult* result)
                     }
                 }
 
-                FF_STRBUF_AUTO_DESTROY name = ffStrbufCreate();
+
+                ffStrbufClear(&name);
 
                 for (int iProp = 0; iProp < conn->count_props; ++iProp)
                 {
@@ -339,12 +352,14 @@ static const char* drmConnectLibdrm(FFDisplayServerResult* result)
                     0,
                     0,
                     &name,
-                    conn->connector_type == DRM_MODE_CONNECTOR_eDP
+                    conn->connector_type == DRM_MODE_CONNECTOR_eDP || conn->connector_type == DRM_MODE_CONNECTOR_LVDS
                         ? FF_DISPLAY_TYPE_BUILTIN
-                        : conn->connector_type == DRM_MODE_CONNECTOR_HDMIA || conn->connector_type == DRM_MODE_CONNECTOR_HDMIB
+                        : conn->connector_type == DRM_MODE_CONNECTOR_HDMIA || conn->connector_type == DRM_MODE_CONNECTOR_HDMIB || conn->connector_type == DRM_MODE_CONNECTOR_DisplayPort
                             ? FF_DISPLAY_TYPE_EXTERNAL : FF_DISPLAY_TYPE_UNKNOWN,
                     false,
-                    conn->connector_id
+                    conn->connector_id,
+                    conn->mmWidth,
+                    conn->mmHeight
                 );
             }
 
