@@ -58,9 +58,9 @@ static void x11DetectWMFromEWMH(X11PropertyData* data, Display* display, FFDispl
     data->ffXFree(wmWindow);
 }
 
-void ffdsConnectXlib(const FFinstance* instance, FFDisplayServerResult* result)
+void ffdsConnectXlib(FFDisplayServerResult* result)
 {
-    FF_LIBRARY_LOAD(x11, &instance->config.libX11, , "libX11" FF_LIBRARY_EXTENSION, 7, "libX11-xcb" FF_LIBRARY_EXTENSION, 2)
+    FF_LIBRARY_LOAD(x11, &instance.config.library.libX11, , "libX11" FF_LIBRARY_EXTENSION, 7, "libX11-xcb" FF_LIBRARY_EXTENSION, 2)
     FF_LIBRARY_LOAD_SYMBOL(x11, XOpenDisplay,)
     FF_LIBRARY_LOAD_SYMBOL(x11, XCloseDisplay,)
 
@@ -83,8 +83,13 @@ void ffdsConnectXlib(const FFinstance* instance, FFDisplayServerResult* result)
             0,
             (uint32_t) WidthOfScreen(screen),
             (uint32_t) HeightOfScreen(screen),
+            0,
             NULL,
-            FF_DISPLAY_TYPE_UNKNOWN
+            FF_DISPLAY_TYPE_UNKNOWN,
+            false,
+            0,
+            (uint32_t) WidthMMOfScreen(screen),
+            (uint32_t) HeightMMOfScreen(screen)
         );
     }
 
@@ -97,68 +102,55 @@ void ffdsConnectXlib(const FFinstance* instance, FFDisplayServerResult* result)
 
 #else
 
-void ffdsConnectXlib(const FFinstance* instance, FFDisplayServerResult* result)
+void ffdsConnectXlib(FFDisplayServerResult* result)
 {
     //Do nothing. WM / DE detection will use environment vars to detect as much as possible.
-    FF_UNUSED(instance, result);
+    FF_UNUSED(result);
 }
 
 #endif //FF_HAVE_X11
 
 #ifdef FF_HAVE_XRANDR
+#include "util/edidHelper.h"
 #include <X11/extensions/Xrandr.h>
 
 typedef struct XrandrData
 {
-    FF_LIBRARY_SYMBOL(XRRGetScreenInfo)
-    FF_LIBRARY_SYMBOL(XRRConfigCurrentConfiguration)
-    FF_LIBRARY_SYMBOL(XRRConfigCurrentRate)
+    FF_LIBRARY_SYMBOL(XInternAtom)
+    FF_LIBRARY_SYMBOL(XGetAtomName);
+    FF_LIBRARY_SYMBOL(XFree);
     FF_LIBRARY_SYMBOL(XRRGetMonitors)
-    FF_LIBRARY_SYMBOL(XRRGetScreenResources)
+    FF_LIBRARY_SYMBOL(XRRGetScreenResourcesCurrent)
     FF_LIBRARY_SYMBOL(XRRGetOutputInfo)
+    FF_LIBRARY_SYMBOL(XRRGetOutputProperty)
     FF_LIBRARY_SYMBOL(XRRGetCrtcInfo)
     FF_LIBRARY_SYMBOL(XRRFreeCrtcInfo)
     FF_LIBRARY_SYMBOL(XRRFreeOutputInfo)
     FF_LIBRARY_SYMBOL(XRRFreeScreenResources)
     FF_LIBRARY_SYMBOL(XRRFreeMonitors)
-    FF_LIBRARY_SYMBOL(XRRFreeScreenConfigInfo)
 
     //Init once
     Display* display;
     FFDisplayServerResult* result;
 
     //Init per screen
-    uint32_t defaultRefreshRate;
     XRRScreenResources* screenResources;
 } XrandrData;
 
-static bool xrandrHandleModeInfo(XrandrData* data, XRRModeInfo* modeInfo)
-{
-    double refreshRate = (double) modeInfo->dotClock / (double) (modeInfo->hTotal * modeInfo->vTotal);
-
-    return ffdsAppendDisplay(
-        data->result,
-        (uint32_t) modeInfo->width,
-        (uint32_t) modeInfo->height,
-        refreshRate == 0 ? data->defaultRefreshRate : refreshRate,
-        (uint32_t) modeInfo->width,
-        (uint32_t) modeInfo->height,
-        NULL,
-        FF_DISPLAY_TYPE_UNKNOWN
-    );
-}
-
-static bool xrandrHandleMode(XrandrData* data, RRMode mode)
+static double xrandrHandleMode(XrandrData* data, RRMode mode)
 {
     for(int i = 0; i < data->screenResources->nmode; i++)
     {
         if(data->screenResources->modes[i].id == mode)
-            return xrandrHandleModeInfo(data, &data->screenResources->modes[i]);
+        {
+            XRRModeInfo* modeInfo = &data->screenResources->modes[i];
+            return (double) modeInfo->dotClock / (double) (modeInfo->hTotal * modeInfo->vTotal);
+        }
     }
-    return false;
+    return 0;
 }
 
-static bool xrandrHandleCrtc(XrandrData* data, RRCrtc crtc)
+static bool xrandrHandleCrtc(XrandrData* data, RRCrtc crtc, FFstrbuf* name, bool primary, XRROutputInfo* output, FFDisplayType displayType)
 {
     //We do the check here, because we want the best fallback display if this call failed
     if(data->screenResources == NULL)
@@ -168,29 +160,68 @@ static bool xrandrHandleCrtc(XrandrData* data, RRCrtc crtc)
     if(crtcInfo == NULL)
         return false;
 
-    bool res = xrandrHandleMode(data, crtcInfo->mode);
-    res = res ? true : ffdsAppendDisplay(
+    uint32_t rotation;
+    switch (crtcInfo->rotation)
+    {
+        case RR_Rotate_90:
+            rotation = 90;
+            break;
+        case RR_Rotate_180:
+            rotation = 180;
+            break;
+        case RR_Rotate_270:
+            rotation = 270;
+            break;
+        default:
+            rotation = 0;
+            break;
+    }
+
+    bool res = ffdsAppendDisplay(
         data->result,
         (uint32_t) crtcInfo->width,
         (uint32_t) crtcInfo->height,
-        data->defaultRefreshRate,
+        xrandrHandleMode(data, crtcInfo->mode),
         (uint32_t) crtcInfo->width,
         (uint32_t) crtcInfo->height,
-        NULL,
-        FF_DISPLAY_TYPE_UNKNOWN
+        rotation,
+        name,
+        displayType,
+        primary,
+        0,
+        (uint32_t) output->mm_width,
+        (uint32_t) output->mm_height
     );
 
     data->ffXRRFreeCrtcInfo(crtcInfo);
     return res;
 }
 
-static bool xrandrHandleOutput(XrandrData* data, RROutput output)
+static bool xrandrHandleOutput(XrandrData* data, RROutput output, FFstrbuf* name, bool primary, FFDisplayType displayType)
 {
     XRROutputInfo* outputInfo = data->ffXRRGetOutputInfo(data->display, data->screenResources, output);
     if(outputInfo == NULL)
         return false;
 
-    bool res = xrandrHandleCrtc(data, outputInfo->crtc);
+    Atom atomEdid = data->ffXInternAtom(data->display, "EDID", true);
+    if (atomEdid != None)
+    {
+        int actual_format = 0;
+        unsigned long nitems = 0, bytes_after = 0;
+        Atom actual_type = None;
+        uint8_t* edidData = NULL;
+        if (data->ffXRRGetOutputProperty(data->display, output, atomEdid, 0, 100, false, false, AnyPropertyType, &actual_type, &actual_format, &nitems, &bytes_after, &edidData) == Success)
+        {
+            if (nitems >= 128)
+            {
+                ffStrbufClear(name);
+                ffEdidGetName(edidData, name);
+            }
+        }
+        if (edidData)
+            data->ffXFree(edidData);
+    }
+    bool res = xrandrHandleCrtc(data, outputInfo->crtc, name, primary, outputInfo, displayType);
 
     data->ffXRRFreeOutputInfo(outputInfo);
 
@@ -200,22 +231,30 @@ static bool xrandrHandleOutput(XrandrData* data, RROutput output)
 static bool xrandrHandleMonitor(XrandrData* data, XRRMonitorInfo* monitorInfo)
 {
     bool foundOutput = false;
-
+    char* xname = data->ffXGetAtomName(data->display, monitorInfo->name);
+    FF_STRBUF_AUTO_DESTROY name = ffStrbufCreateS(xname);
+    data->ffXFree(xname);
+    FFDisplayType displayType = ffdsGetDisplayType(name.chars);
     for(int i = 0; i < monitorInfo->noutput; i++)
     {
-        if(xrandrHandleOutput(data, monitorInfo->outputs[i]))
+        if(xrandrHandleOutput(data, monitorInfo->outputs[i], &name, monitorInfo->primary, displayType))
             foundOutput = true;
     }
 
-    return foundOutput ? true : ffdsAppendDisplay(
+    return foundOutput ? true : !!ffdsAppendDisplay(
         data->result,
         (uint32_t) monitorInfo->width,
         (uint32_t) monitorInfo->height,
-        data->defaultRefreshRate,
+        0,
         (uint32_t) monitorInfo->width,
         (uint32_t) monitorInfo->height,
-        NULL,
-        FF_DISPLAY_TYPE_UNKNOWN
+        0,
+        &name,
+        displayType,
+        !!monitorInfo->primary,
+        0,
+        (uint32_t) monitorInfo->mwidth,
+        (uint32_t) monitorInfo->mheight
     );
 }
 
@@ -241,19 +280,8 @@ static bool xrandrHandleMonitors(XrandrData* data, Screen* screen)
 
 static void xrandrHandleScreen(XrandrData* data, Screen* screen)
 {
-    //Init screen configuration. This is used to get the default refresh rate. If this fails, default refresh rate is simply 0.
-    XRRScreenConfiguration* screenConfiguration = data->ffXRRGetScreenInfo(data->display, RootWindowOfScreen(screen));
-
-    if(screenConfiguration != NULL)
-    {
-        data->defaultRefreshRate = (uint32_t) data->ffXRRConfigCurrentRate(screenConfiguration);
-        data->ffXRRFreeScreenConfigInfo(screenConfiguration);
-    }
-    else
-        data->defaultRefreshRate = 0;
-
     //Init screen resources
-    data->screenResources = data->ffXRRGetScreenResources(data->display, RootWindowOfScreen(screen));
+    data->screenResources = data->ffXRRGetScreenResourcesCurrent(data->display, RootWindowOfScreen(screen));
 
     bool ret = xrandrHandleMonitors(data, screen);
 
@@ -267,34 +295,40 @@ static void xrandrHandleScreen(XrandrData* data, Screen* screen)
         data->result,
         (uint32_t) WidthOfScreen(screen),
         (uint32_t) HeightOfScreen(screen),
-        data->defaultRefreshRate,
+        0,
         (uint32_t) WidthOfScreen(screen),
         (uint32_t) HeightOfScreen(screen),
+        0,
         NULL,
-        FF_DISPLAY_TYPE_UNKNOWN
+        FF_DISPLAY_TYPE_UNKNOWN,
+        false,
+        0,
+        (uint32_t) WidthMMOfScreen(screen),
+        (uint32_t) HeightMMOfScreen(screen)
     );
 }
 
-void ffdsConnectXrandr(const FFinstance* instance, FFDisplayServerResult* result)
+void ffdsConnectXrandr(FFDisplayServerResult* result)
 {
-    FF_LIBRARY_LOAD(xrandr, &instance->config.libXrandr, , "libXrandr" FF_LIBRARY_EXTENSION, 3)
+    FF_LIBRARY_LOAD(xrandr, &instance.config.library.libXrandr, , "libXrandr" FF_LIBRARY_EXTENSION, 3)
 
     FF_LIBRARY_LOAD_SYMBOL(xrandr, XOpenDisplay,)
     FF_LIBRARY_LOAD_SYMBOL(xrandr, XCloseDisplay,)
 
     XrandrData data;
 
-    FF_LIBRARY_LOAD_SYMBOL_VAR(xrandr, data, XRRGetScreenInfo,)
-    FF_LIBRARY_LOAD_SYMBOL_VAR(xrandr, data, XRRConfigCurrentRate,);
+    FF_LIBRARY_LOAD_SYMBOL_VAR(xrandr, data, XInternAtom,);
+    FF_LIBRARY_LOAD_SYMBOL_VAR(xrandr, data, XGetAtomName,);
+    FF_LIBRARY_LOAD_SYMBOL_VAR(xrandr, data, XFree,);
     FF_LIBRARY_LOAD_SYMBOL_VAR(xrandr, data, XRRGetMonitors,);
-    FF_LIBRARY_LOAD_SYMBOL_VAR(xrandr, data, XRRGetScreenResources,);
+    FF_LIBRARY_LOAD_SYMBOL_VAR(xrandr, data, XRRGetScreenResourcesCurrent,);
     FF_LIBRARY_LOAD_SYMBOL_VAR(xrandr, data, XRRGetOutputInfo,);
+    FF_LIBRARY_LOAD_SYMBOL_VAR(xrandr, data, XRRGetOutputProperty,);
     FF_LIBRARY_LOAD_SYMBOL_VAR(xrandr, data, XRRGetCrtcInfo,);
     FF_LIBRARY_LOAD_SYMBOL_VAR(xrandr, data, XRRFreeCrtcInfo,);
     FF_LIBRARY_LOAD_SYMBOL_VAR(xrandr, data, XRRFreeOutputInfo,);
     FF_LIBRARY_LOAD_SYMBOL_VAR(xrandr, data, XRRFreeScreenResources,);
     FF_LIBRARY_LOAD_SYMBOL_VAR(xrandr, data, XRRFreeMonitors,);
-    FF_LIBRARY_LOAD_SYMBOL_VAR(xrandr, data, XRRFreeScreenConfigInfo,);
 
     X11PropertyData propertyData;
     bool propertyDataInitialized = x11InitPropertyData(xrandr, &propertyData);
@@ -320,10 +354,10 @@ void ffdsConnectXrandr(const FFinstance* instance, FFDisplayServerResult* result
 
 #else
 
-void ffdsConnectXrandr(const FFinstance* instance, FFDisplayServerResult* result)
+void ffdsConnectXrandr(FFDisplayServerResult* result)
 {
-    //Do nothing here. There are more x11 implementaions to come.
-    FF_UNUSED(instance, result);
+    //Do nothing here. There are more x11 implementations to come.
+    FF_UNUSED(result);
 }
 
 #endif // FF_HAVE_XRANDR
