@@ -141,11 +141,11 @@ static bool isValidNixPkg(FFstrbuf* pkg)
         switch (state)
         {
             case START:
-                if (c >= '0' && c <= '9')
+                if (ffCharIsDigit(c))
                     state = DIGIT;
                 break;
             case DIGIT:
-                if (c >= '0' && c <= '9')
+                if (ffCharIsDigit(c))
                     continue;
                 if (c == '.')
                     state = DOT;
@@ -153,7 +153,7 @@ static bool isValidNixPkg(FFstrbuf* pkg)
                     state = START;
                 break;
             case DOT:
-                if (c >= '0' && c <= '9')
+                if (ffCharIsDigit(c))
                     state = MATCH;
                 else
                     state = START;
@@ -313,19 +313,6 @@ static uint32_t getSnap(FFstrbuf* baseDir)
     return result > 0 ? result - 1 : 0;
 }
 
-static uint32_t getFlatpak(FFstrbuf* baseDir, const char* dirname)
-{
-    uint32_t baseDirLength = baseDir->length;
-    ffStrbufAppendS(baseDir, dirname);
-
-    uint32_t result =
-        getNumElements(baseDir, "/app", DT_DIR) +
-        getNumElements(baseDir, "/runtime", DT_DIR);
-
-    ffStrbufSubstrBefore(baseDir, baseDirLength);
-    return result;
-}
-
 #ifdef FF_HAVE_RPM
 #include "common/library.h"
 #include <rpm/rpmlib.h>
@@ -408,6 +395,50 @@ static uint32_t getAM(FFstrbuf* baseDir)
     return result;
 }
 
+static int compareHash(const void* a, const void* b)
+{
+    return memcmp(a, b, 32);
+}
+
+static uint32_t getGuixPackagesImpl(char* filename)
+{
+    FF_STRBUF_AUTO_DESTROY content = ffStrbufCreate();
+    if (!ffAppendFileBuffer(filename, &content))
+        return 0;
+
+    // Count number of unique /gnu/store/ paths in PROFILE/manifest based on their hash value.
+    // Contains packages explicitly installed and their propagated inputs.
+    char* pend = content.chars;
+
+    for (const char* pattern = content.chars; (pattern = strstr(pattern, "/gnu/store/")); pattern += 32)
+    {
+        pattern += strlen("/gnu/store/");
+        memmove(pend, pattern, 32);
+        pend += 32;
+    }
+
+    if (pend == content.chars)
+        return 0;
+
+    qsort(content.chars, (size_t) (pend - content.chars) / 32, 32, compareHash);
+
+    uint32_t count = 1;
+    for (const char* p = content.chars + 32; p < pend; p += 32)
+        count += compareHash(p - 32, p) != 0;
+
+    return count;
+}
+
+static uint32_t getGuixPackages(FFstrbuf* baseDir, const char* dirname)
+{
+    uint32_t baseDirLength = baseDir->length;
+    ffStrbufAppendS(baseDir, dirname);
+    ffStrbufAppendS(baseDir, "/manifest");
+    uint32_t num_elements = getGuixPackagesImpl(baseDir->chars);
+    ffStrbufSubstrBefore(baseDir, baseDirLength);
+    return num_elements;
+}
+
 static void getPackageCounts(FFstrbuf* baseDir, FFPackagesResult* packageCounts, FFPackagesOptions* options)
 {
     if (!(options->disabled & FF_PACKAGES_FLAG_APK_BIT)) packageCounts->apk += getNumStrings(baseDir, "/lib/apk/db/installed", "C:Q");
@@ -415,7 +446,7 @@ static void getPackageCounts(FFstrbuf* baseDir, FFPackagesResult* packageCounts,
     if (!(options->disabled & FF_PACKAGES_FLAG_LPKG_BIT)) packageCounts->lpkg += getNumStrings(baseDir, "/opt/Loc-OS-LPKG/installed-lpkg/Listinstalled-lpkg.list", "\n");
     if (!(options->disabled & FF_PACKAGES_FLAG_EMERGE_BIT)) packageCounts->emerge += countFilesRecursive(baseDir, "/var/db/pkg", "SIZE");
     if (!(options->disabled & FF_PACKAGES_FLAG_EOPKG_BIT)) packageCounts->eopkg += getNumElements(baseDir, "/var/lib/eopkg/package", DT_DIR);
-    if (!(options->disabled & FF_PACKAGES_FLAG_FLATPAK_BIT)) packageCounts->flatpakSystem += getFlatpak(baseDir, "/var/lib/flatpak");
+    if (!(options->disabled & FF_PACKAGES_FLAG_FLATPAK_BIT)) packageCounts->flatpakSystem += getNumElements(baseDir, "/var/lib/flatpak/app", DT_DIR);
     if (!(options->disabled & FF_PACKAGES_FLAG_NIX_BIT))
     {
         packageCounts->nixDefault += getNixPackages(baseDir, "/nix/var/nix/profiles/default");
@@ -436,6 +467,11 @@ static void getPackageCounts(FFstrbuf* baseDir, FFPackagesResult* packageCounts,
     if (!(options->disabled & FF_PACKAGES_FLAG_OPKG_BIT)) packageCounts->opkg += getNumStrings(baseDir, "/usr/lib/opkg/status", "Package:"); // openwrt
     if (!(options->disabled & FF_PACKAGES_FLAG_AM_BIT)) packageCounts->am = getAM(baseDir);
     if (!(options->disabled & FF_PACKAGES_FLAG_SORCERY_BIT)) packageCounts->sorcery += getNumStrings(baseDir, "/var/state/sorcery/packages", ":installed:");
+    if (!(options->disabled & FF_PACKAGES_FLAG_GUIX_BIT))
+    {
+      packageCounts->guixSystem += getGuixPackages(baseDir, "/run/current-system/profile");
+    }
+    if (!(options->disabled & FF_PACKAGES_FLAG_LINGLONG_BIT)) packageCounts->linglong += getNumElements(baseDir, "/var/lib/linglong/repo/refs/heads/main", DT_DIR);
 }
 
 static void getPackageCountsRegular(FFstrbuf* baseDir, FFPackagesResult* packageCounts, FFPackagesOptions* options)
@@ -532,6 +568,12 @@ void ffDetectPackagesImpl(FFPackagesResult* result, FFPackagesOptions* options)
         result->nixUser += getNixPackages(&stateDir, "nix/profile");
     }
 
+    if (!(options->disabled & FF_PACKAGES_FLAG_GUIX_BIT))
+    {
+       result->guixUser += getGuixPackages(&baseDir, ".guix-profile");
+       result->guixHome += getGuixPackages(&baseDir, ".guix-home/profile");
+    }
+
     if (!(options->disabled & FF_PACKAGES_FLAG_FLATPAK_BIT))
-        result->flatpakUser = getFlatpak(&baseDir, "/.local/share/flatpak");
+        result->flatpakUser = getNumElements(&baseDir, "/.local/share/flatpak/app", DT_DIR);
 }
