@@ -3,6 +3,7 @@
 #include "common/processing.h"
 #include "common/properties.h"
 #include "util/stringUtils.h"
+#include "util/binary.h"
 
 #include <ctype.h>
 #ifdef __FreeBSD__
@@ -63,16 +64,29 @@ static bool getExeVersionGeneral(FFstrbuf* exe, FFstrbuf* version)
     return true;
 }
 
-static bool getShellVersionBash(FFstrbuf* exe, FFstrbuf* version)
+static bool extractBashVersion(const char* line, FF_MAYBE_UNUSED uint32_t len, void *userdata)
 {
+    if (!ffStrStartsWith(line, "@(#)Bash version ")) return true;
+    const char* start = line + strlen("@(#)Bash version ");
+    const char* end = strchr(start, '(');
+    if (!end) return true;
+    ffStrbufSetNS((FFstrbuf*) userdata, (uint32_t) (end - start), start);
+    return false;
+}
+
+static bool getShellVersionBash(FFstrbuf* exe, FFstrbuf* exePath, FFstrbuf* version)
+{
+    const char* path = exePath->chars;
+    if (*path == '\0')
+        path = exe->chars;
+    ffBinaryExtractStrings(path, extractBashVersion, version, (uint32_t) strlen("@(#)Bash version 0.0.0(0) release GNU"));
+
     if(!getExeVersionRaw(exe, version))
         return false;
 
     // GNU bash, version 5.1.16(1)-release (x86_64-pc-msys)\nCopyright...
-    ffStrbufSubstrBeforeFirstC(version, '\n'); // GNU bash, version 5.1.16(1)-release (x86_64-pc-msys)
-    ffStrbufSubstrBeforeLastC(version, ' '); // GNU bash, version 5.1.16(1)-release
-    ffStrbufSubstrAfterLastC(version, ' '); // 5.1.16(1)-release
-    ffStrbufSubstrBeforeFirstC(version, '('); // 5.1.16
+    ffStrbufSubstrBeforeFirstC(version, '('); // GNU bash, version 5.1.16
+    ffStrbufSubstrAfterLastC(version, ' '); // 5.1.16
     return true;
 }
 
@@ -188,6 +202,29 @@ static bool getShellVersionXonsh(FFstrbuf* exe, FFstrbuf* version)
     return true;
 }
 
+static bool extractZshVersion(const char* line, FF_MAYBE_UNUSED uint32_t len, void *userdata)
+{
+    if (!ffStrStartsWith(line, "zsh-")) return true;
+    const char* start = line + strlen("zsh-");
+    const char* end = strchr(start, '-');
+    if (!end) return true;
+
+    ffStrbufSetNS((FFstrbuf*) userdata, (uint32_t) (end - start), start);
+    return false;
+}
+
+static bool getShellVersionZsh(FFstrbuf* exe, FFstrbuf* exePath, FFstrbuf* version)
+{
+    const char* path = exePath->chars;
+    if (*path == '\0')
+        path = exe->chars;
+
+    ffBinaryExtractStrings(path, extractZshVersion, version, (uint32_t) strlen("zsh-0.0-0"));
+    if (version->length) return true;
+
+    return getExeVersionGeneral(exe, version); //zsh 5.9 (arm-apple-darwin21.3.0)
+}
+
 #ifdef _WIN32
 static bool getShellVersionWinPowerShell(FFstrbuf* exe, FFstrbuf* version)
 {
@@ -200,70 +237,48 @@ static bool getShellVersionWinPowerShell(FFstrbuf* exe, FFstrbuf* version)
         NULL
     }) == NULL;
 }
-#else
-static bool getShellVersionGeneric(FFstrbuf* exe, const char* exeName, FFstrbuf* version)
-{
-    FF_STRBUF_AUTO_DESTROY command = ffStrbufCreate();
-    ffStrbufAppendS(&command, "printf \"%s\" \"$");
-    ffStrbufAppendTransformS(&command, exeName, toupper);
-    ffStrbufAppendS(&command, "_VERSION\"");
-
-    if (ffProcessAppendStdOut(version, (char* const[]) {
-        "env",
-        "-i",
-        exe->chars,
-        "-c",
-        command.chars,
-        NULL
-    }) != NULL)
-        return false;
-
-    ffStrbufSubstrBeforeFirstC(version, '(');
-    ffStrbufRemoveStrings(version, 2, (const char*[]) { "-release", "release" });
-    return true;
-}
 #endif
 
-bool fftsGetShellVersion(FFstrbuf* exe, const char* exeName, FFstrbuf* version)
+bool fftsGetShellVersion(FFstrbuf* exe, const char* exeName, FFstrbuf* exePath, FFstrbuf* version)
 {
-    if (!instance.config.display.tsVersion) return false;
+    if (!instance.config.general.detectVersion) return false;
 
     if(ffStrEqualsIgnCase(exeName, "sh")) // #849
         return false;
 
-    if(strcasecmp(exeName, "bash") == 0)
-        return getShellVersionBash(exe, version);
-    if(strcasecmp(exeName, "zsh") == 0)
-        return getExeVersionGeneral(exe, version); //zsh 5.9 (arm-apple-darwin21.3.0)
-    if(strcasecmp(exeName, "fish") == 0)
+    if(ffStrEqualsIgnCase(exeName, "bash"))
+        return getShellVersionBash(exe, exePath, version);
+    if(ffStrEqualsIgnCase(exeName, "zsh"))
+        return getShellVersionZsh(exe, exePath, version);
+    if(ffStrEqualsIgnCase(exeName, "fish"))
         return getShellVersionFish(exe, version);
-    if(strcasecmp(exeName, "pwsh") == 0)
+    if(ffStrEqualsIgnCase(exeName, "pwsh"))
         return getShellVersionPwsh(exe, version);
-    if(strcasecmp(exeName, "csh") == 0 || strcasecmp(exeName, "tcsh") == 0)
+    if(ffStrEqualsIgnCase(exeName, "csh") || ffStrEqualsIgnCase(exeName, "tcsh"))
         return getExeVersionGeneral(exe, version); //tcsh 6.24.07 (Astron) 2022-12-21 (aarch64-apple-darwin) options wide,nls,dl,al,kan,sm,rh,color,filec
-    if(strcasecmp(exeName, "nu") == 0)
+    if(ffStrEqualsIgnCase(exeName, "nu"))
         return getShellVersionNushell(exe, version);
-    if(strcasecmp(exeName, "ksh") == 0)
+    if(ffStrEqualsIgnCase(exeName, "ksh"))
         return getShellVersionKsh(exe, version);
-    if(strcasecmp(exeName, "oksh") == 0)
+    if(ffStrEqualsIgnCase(exeName, "oksh"))
         return getShellVersionOksh(exe, version);
-    if(strcasecmp(exeName, "oil.ovm") == 0)
+    if(ffStrEqualsIgnCase(exeName, "oil.ovm"))
         return getShellVersionOils(exe, version);
-    if(strcasecmp(exeName, "elvish") == 0)
+    if(ffStrEqualsIgnCase(exeName, "elvish"))
         return getExeVersionRaw(exe, version);
-    if(strcasecmp(exeName, "ash") == 0)
+    if(ffStrEqualsIgnCase(exeName, "ash"))
         return getShellVersionAsh(exe, version);
-    if(strcasecmp(exeName, "xonsh") == 0)
+    if(ffStrEqualsIgnCase(exeName, "xonsh"))
         return getShellVersionXonsh(exe, version);
 
     #ifdef _WIN32
-    if(strcasecmp(exeName, "powershell") == 0 || strcasecmp(exeName, "powershell_ise") == 0)
+    if(ffStrEqualsIgnCase(exeName, "powershell") || ffStrEqualsIgnCase(exeName, "powershell_ise"))
         return getShellVersionWinPowerShell(exe, version);
 
     return getFileVersion(exe->chars, version);
-    #else
-    return getShellVersionGeneric(exe, exeName, version);
     #endif
+
+    return false;
 }
 
 FF_MAYBE_UNUSED static bool getTerminalVersionTermux(FFstrbuf* version)
@@ -272,8 +287,24 @@ FF_MAYBE_UNUSED static bool getTerminalVersionTermux(FFstrbuf* version)
     return version->length > 0;
 }
 
-FF_MAYBE_UNUSED static bool getTerminalVersionGnome(FFstrbuf* version)
+static bool extractGeneralVersion(const char *str, FF_MAYBE_UNUSED uint32_t len, void *userdata)
 {
+    if (!ffCharIsDigit(str[0])) return true;
+    int count = 0;
+    sscanf(str, "%*d.%*d.%*d%n", &count);
+    if (count == 0) return true;
+    ffStrbufSetS((FFstrbuf*) userdata, str);
+    return false;
+}
+
+FF_MAYBE_UNUSED static bool getTerminalVersionGnome(FFstrbuf* exe, FFstrbuf* version)
+{
+    if (exe->chars[0] == '/')
+    {
+        ffBinaryExtractStrings(exe->chars, extractGeneralVersion, version, (uint32_t) strlen("0.0.0"));
+        if (version->length) return true;
+    }
+
     if(ffProcessAppendStdOut(version, (char* const[]){
         "gnome-terminal",
         "--version",
@@ -286,6 +317,17 @@ FF_MAYBE_UNUSED static bool getTerminalVersionGnome(FFstrbuf* version)
     return true;
 }
 
+FF_MAYBE_UNUSED static bool getTerminalVersionXfce4Terminal(FFstrbuf* exe, FFstrbuf* version)
+{
+    if (exe->chars[0] == '/')
+    {
+        ffBinaryExtractStrings(exe->chars, extractGeneralVersion, version, (uint32_t) strlen("0.0.0"));
+        if (version->length) return true;
+    }
+
+    return getExeVersionGeneral(exe, version);//xfce4-terminal 1.0.4 (Xfce 4.18)...
+}
+
 FF_MAYBE_UNUSED static bool getTerminalVersionKgx(FFstrbuf* version)
 {
     if(ffProcessAppendStdOut(version, (char* const[]){
@@ -352,11 +394,15 @@ FF_MAYBE_UNUSED static bool getTerminalVersionCockpit(FFstrbuf* exe, FFstrbuf* v
 
 FF_MAYBE_UNUSED static bool getTerminalVersionXterm(FFstrbuf* exe, FFstrbuf* version)
 {
-    if(ffProcessAppendStdOut(version, (char* const[]){
-        exe->chars,
-        "-v",
-        NULL
-    })) return false;
+    ffStrbufSetS(version, getenv("XTERM_VERSION"));
+    if (!version->length)
+    {
+        if(ffProcessAppendStdOut(version, (char* const[]){
+            exe->chars,
+            "-v",
+            NULL
+        })) return false;
+    }
 
     //xterm(273)
     ffStrbufTrimRight(version, ')');
@@ -477,11 +523,33 @@ static bool getTerminalVersionZellij(FFstrbuf* exe, FFstrbuf* version)
     return version->length > 0;
 }
 
+static bool getTerminalVersionZed(FFstrbuf* exe, FFstrbuf* version)
+{
+    FF_STRBUF_AUTO_DESTROY cli = ffStrbufCreateCopy(exe);
+    ffStrbufSubstrBeforeLastC(&cli, '/');
+    ffStrbufAppendS(&cli, "/cli"
+        #ifdef _WIN32
+            ".exe"
+        #endif
+    );
+
+    if(ffProcessAppendStdOut(version, (char* const[]) {
+        cli.chars,
+        "--version",
+        NULL
+    }) != NULL)
+        return false;
+
+    // Zed 0.142.6 – /Applications/Zed.app
+    ffStrbufSubstrAfterFirstC(version, ' ');
+    ffStrbufSubstrBeforeFirstC(version, ' ');
+    return true;
+}
+
 #ifndef _WIN32
 static bool getTerminalVersionKitty(FFstrbuf* exe, FFstrbuf* version)
 {
     #if defined(__linux__) || defined(__FreeBSD__)
-    // kitty is written in python. `kitty --version` can be expensive
     char buffer[1024] = {};
     if (
         #ifdef __linux__
@@ -508,9 +576,39 @@ static bool getTerminalVersionKitty(FFstrbuf* exe, FFstrbuf* version)
     }
     #endif
 
+    char versionHex[64];
+    // https://github.com/fastfetch-cli/fastfetch/discussions/1030#discussioncomment-9845233
+    if (ffGetTerminalResponse(
+        "\eP+q6b697474792d71756572792d76657273696f6e\e\\", // kitty-query-version
+        "\eP1+r%*[^=]=%63[^\e]\e\\\\", versionHex) == NULL)
+    {
+        // decode hex string
+        for (const char* p = versionHex; p[0] && p[1]; p += 2)
+        {
+            unsigned value;
+            if (sscanf(p, "%2x", &value) == 1)
+                ffStrbufAppendC(version, (char) value);
+        }
+        return true;
+    }
+
     //kitty 0.21.2 created by Kovid Goyal
     return getExeVersionGeneral(exe, version);
 }
+
+FF_MAYBE_UNUSED static bool getTerminalVersionPtyxis(FF_MAYBE_UNUSED FFstrbuf* exe, FFstrbuf* version)
+{
+    if(ffProcessAppendStdOut(version, (char* const[]) {
+        "ptyxis",
+        "--version",
+        NULL
+    }) != NULL)
+        return false;
+
+    ffStrbufSubstrBeforeFirstC(version, '\n');
+    ffStrbufSubstrAfterFirstC(version, ' ');
+    return true;
+}
 #endif
 
 #ifdef _WIN32
@@ -544,7 +642,7 @@ static bool getTerminalVersionConEmu(FFstrbuf* exe, FFstrbuf* version)
 
 bool fftsGetTerminalVersion(FFstrbuf* processName, FF_MAYBE_UNUSED FFstrbuf* exe, FFstrbuf* version)
 {
-    if (!instance.config.display.tsVersion) return false;
+    if (!instance.config.general.detectVersion) return false;
 
     #ifdef __ANDROID__
 
@@ -553,10 +651,10 @@ bool fftsGetTerminalVersion(FFstrbuf* processName, FF_MAYBE_UNUSED FFstrbuf* exe
 
     #endif
 
-    #if defined(__linux__) || defined(__FreeBSD__)
+    #if defined(__linux__) || defined(__FreeBSD__) || defined(__sun)
 
     if(ffStrbufStartsWithIgnCaseS(processName, "gnome-terminal"))
-        return getTerminalVersionGnome(version);
+        return getTerminalVersionGnome(exe, version);
 
     if(ffStrbufIgnCaseEqualS(processName, "konsole"))
         return getTerminalVersionKonsole(exe, version);
@@ -565,7 +663,7 @@ bool fftsGetTerminalVersion(FFstrbuf* processName, FF_MAYBE_UNUSED FFstrbuf* exe
         return getExeVersionGeneral(exe, version);//yakuake 22.12.3
 
     if(ffStrbufIgnCaseEqualS(processName, "xfce4-terminal"))
-        return getExeVersionGeneral(exe, version);//xfce4-terminal 1.0.4 (Xfce 4.18)...
+        return getTerminalVersionXfce4Terminal(exe, version);
 
     if(ffStrbufIgnCaseEqualS(processName, "terminator"))
         return getExeVersionGeneral(exe, version);//terminator 2.1.3
@@ -607,6 +705,9 @@ bool fftsGetTerminalVersion(FFstrbuf* processName, FF_MAYBE_UNUSED FFstrbuf* exe
     )
         return getTerminalVersionUrxvt(exe, version);
 
+    if(ffStrbufIgnCaseEqualS(processName, "ptyxis-agent"))
+        return getTerminalVersionPtyxis(exe, version);
+
     #endif
 
     #ifdef _WIN32
@@ -641,6 +742,9 @@ bool fftsGetTerminalVersion(FFstrbuf* processName, FF_MAYBE_UNUSED FFstrbuf* exe
     if(ffStrbufStartsWithIgnCaseS(processName, "zellij"))
         return getTerminalVersionZellij(exe, version);
 
+    if(ffStrbufStartsWithIgnCaseS(processName, "zed"))
+        return getTerminalVersionZed(exe, version);
+
     const char* termProgramVersion = getenv("TERM_PROGRAM_VERSION");
     if(termProgramVersion)
     {
