@@ -7,6 +7,7 @@
 typedef enum FFColorsSymbol
 {
     FF_COLORS_SYMBOL_BLOCK,
+    FF_COLORS_SYMBOL_BACKGROUND,
     FF_COLORS_SYMBOL_CIRCLE,
     FF_COLORS_SYMBOL_DIAMOND,
     FF_COLORS_SYMBOL_SQUARE,
@@ -14,6 +15,12 @@ typedef enum FFColorsSymbol
     FF_COLORS_SYMBOL_STAR,
 } FFColorsSymbol;
 
+typedef struct FFBlockConfig
+{
+    uint8_t width;
+    uint8_t range[2];
+} FFBlockConfig;
+
 typedef struct FFColorsOptions
 {
     FFModuleBaseInfo moduleInfo;
@@ -21,4 +28,5 @@ typedef struct FFColorsOptions
 
     FFColorsSymbol symbol;
     uint32_t paddingLeft;
+    FFBlockConfig block;
 } FFColorsOptions;
