@@ -5,6 +5,7 @@
 #include "modules/battery/battery.h"
 #include "modules/bios/bios.h"
 #include "modules/bluetooth/bluetooth.h"
+#include "modules/bluetoothradio/bluetoothradio.h"
 #include "modules/brightness/brightness.h"
 #include "modules/board/board.h"
 #include "modules/bootmgr/bootmgr.h"
@@ -23,6 +24,7 @@
 #include "modules/diskio/diskio.h"
 #include "modules/display/display.h"
 #include "modules/de/de.h"
+#include "modules/dns/dns.h"
 #include "modules/editor/editor.h"
 #include "modules/font/font.h"
 #include "modules/gamepad/gamepad.h"
@@ -68,3 +70,4 @@
 #include "modules/wifi/wifi.h"
 #include "modules/wm/wm.h"
 #include "modules/wmtheme/wmtheme.h"
+#include "modules/zpool/zpool.h"
