@@ -1,5 +1,6 @@
 #include "fastfetch.h"
 #include "common/jsonconfig.h"
+#include "common/processing.h"
 #include "options/general.h"
 #include "util/stringUtils.h"
 
@@ -21,6 +22,22 @@ const char* ffOptionsParseGeneralJsonConfig(FFOptionsGeneral* options, yyjson_va
             options->multithreading = yyjson_get_bool(val);
         else if (ffStrEqualsIgnCase(key, "processingTimeout"))
             options->processingTimeout = (int32_t) yyjson_get_int(val);
+        else if (ffStrEqualsIgnCase(key, "preRun"))
+        {
+            FF_STRBUF_AUTO_DESTROY _ = ffStrbufCreate();
+            const char* error = ffProcessAppendStdOut(&_, (char* const[]) {
+                #ifdef _WIN32
+                "cmd.exe", "/C",
+                #else
+                "/bin/sh", "-c",
+                #endif
+                (char*) yyjson_get_str(val), NULL
+            });
+            if (error)
+                return "Failed to execute preRun command";
+        }
+        else if (ffStrEqualsIgnCase(key, "detectVersion"))
+            options->detectVersion = yyjson_get_bool(val);
 
         #if defined(__linux__) || defined(__FreeBSD__) || defined(__sun)
         else if (ffStrEqualsIgnCase(key, "escapeBedrock"))
@@ -51,13 +68,6 @@ const char* ffOptionsParseGeneralJsonConfig(FFOptionsGeneral* options, yyjson_va
             options->wmiTimeout = (int32_t) yyjson_get_int(val);
         #endif
 
-        else if (ffStrEqualsIgnCase(key, "stat"))
-            return "Property `general.stat` has been changed to `display.stat`";
-        else if (ffStrEqualsIgnCase(key, "pipe"))
-            return "Property `general.pipe` has been changed to `display.pipe`";
-        else if (ffStrEqualsIgnCase(key, "allowSlowOperations"))
-            return "Property `general.allowSlowOperations` has been obsoleted. See CHANGELOG for detail";
-
         else
             return "Unknown general property";
     }
@@ -71,6 +81,8 @@ bool ffOptionsParseGeneralCommandLine(FFOptionsGeneral* options, const char* key
         options->multithreading = ffOptionParseBoolean(value);
     else if(ffStrEqualsIgnCase(key, "--processing-timeout"))
         options->processingTimeout = ffOptionParseInt32(key, value);
+    else if(ffStrEqualsIgnCase(key, "--detect-version"))
+        options->detectVersion = ffOptionParseBoolean(value);
 
     #if defined(__linux__) || defined(__FreeBSD__) || defined(__sun)
     else if(ffStrEqualsIgnCase(key, "--escape-bedrock"))
@@ -101,6 +113,7 @@ void ffOptionsInitGeneral(FFOptionsGeneral* options)
 {
     options->processingTimeout = 1000;
     options->multithreading = true;
+    options->detectVersion = true;
 
     #if defined(__linux__) || defined(__FreeBSD__)
     options->escapeBedrock = true;
